Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateOption ¶
type CreateOption func(*writerImpl)
CreateOption allows setting various options on the resulting writer.
func FromToken ¶
func FromToken(sequenceToken string) CreateOption
FromToken allows writing from an arbitrary sequence token.
func WithInputCallback ¶
func WithInputCallback(callback func(*cloudwatchlogs.InputLogEvent)) CreateOption
WithInputCallback allows setting a function introspecting each input log event before it's sent to AWS CloudWatch Logs.
type Group ¶
type Group interface {
cloudwatchlogsiface.CloudWatchLogsAPI
// Create creates a log stream in the managed group and returns an
// implementation of io.Writer to write to it.
Create(ctx context.Context, streamName string, opts ...CreateOption) (io.WriteCloser, error)
// Name of the CloudWatch Logs group owned by this proxy.
Name() string
// Open returns an io.Readcloser to read from the log stream.
Open(ctx context.Context, streamName string) io.ReadCloser
}
Group is an abstraction over AWS CloudWatch Logs Group, allowing one to treat it like a remote io.ReadWriter.
type RejectedLogEventsInfoError ¶
type RejectedLogEventsInfoError struct {
Info *cloudwatchlogs.RejectedLogEventsInfo
}
RejectedLogEventsInfoError wraps `cloudwatchlogs.RejectedLogEventsInfo` from the AWS SDK, and makes it an implementation of Go's error interface.
func (*RejectedLogEventsInfoError) Error ¶
func (e *RejectedLogEventsInfoError) Error() string
Click to show internal directories.
Click to hide internal directories.